@@ -286,7 +286,7 @@ class Link():
 		new_data = self.data.copy()
 		new_data[:,1]=new_fT/new_sB
 
-		return Link(oscA=self.oscB, oscB=self.oscA, data=new_data, r0=new_r0, sB = new_sB)
+		return Link(oscA=self.oscB, oscB=self.oscA, data=new_data, r0=new_r0, sB = new_sB, step=self.step)
 		
 
 	def __sub__(self, other):
@@ -298,6 +298,25 @@ class Link():
 
 
 def chain2(link1, link2):
+	"""Chain 2 links in sequence.
+
+	Parameters
+	----------
+	link1 : link B/A
+		link object to be chained.
+	link2 : link C/B
+		link object to be chained.
+
+	Returns
+	-------
+	res 
+		chained link object C/A.
+	mask1
+		mask to be applied to link1 to select timetags common to link2
+	mask2
+		mask to be applied to link2 to select timetags common to link1
+
+	"""
 	if link1.step != link2.step:
 	 	raise ValueError('Cannot chain links with inconsitent time steps.')
 
@@ -320,7 +339,7 @@ def chain2(link1, link2):
 	
 	
 
-	res = Link(oscB=link2.oscB, oscA=link1.oscA, data=new_data, r0=link1.r0*link2.r0, sB=link1.r0*link2.r0*link1.oscA.v0)
+	res = Link(oscB=link2.oscB, oscA=link1.oscA, data=new_data, r0=link1.r0*link2.r0, sB=link1.r0*link2.r0*link1.oscA.v0, step=link1.step)
 	if res.oscB.v0:
 		res.normalize()
 	
@@ -330,8 +349,25 @@ def chain2(link1, link2):
 
 
 def chain(*links):
-	# if link1.step != link2.step:
-	#  	raise ValueError('Cannot chain links with inconsitent time steps.')
+	"""Chain multiple links in sequence.
+
+	Parameters
+	----------
+	*links :
+		link objects to be chained.
+	
+	Returns
+	-------
+	res 
+		chained link object.
+	masks
+		list of masks to select timetags in the common uptime (one for each link).
+
+	"""
+	step = links[0].step
+	for l in links:
+		if l.step != step:
+			raise ValueError('Cannot chain links with inconsitent time steps.')
 
 	if not links[0].oscA.v0:
 		raise ValueError('Cannot chain links in case the first oscillator in the chain has no nominal value (not accurate oscillator)')
@@ -355,7 +391,7 @@ def chain(*links):
 	
 	
 
-	res = Link(oscB=links[-1].oscB, oscA=links[0].oscA, data=new_data, r0=den[-1], sB=den[-1]*links[0].oscA.v0)
+	res = Link(oscB=links[-1].oscB, oscA=links[0].oscA, data=new_data, r0=den[-1], sB=den[-1]*links[0].oscA.v0, step=step)
 	if res.oscB.v0:
 		res.normalize()
 	
@@ -421,7 +457,7 @@ def link_average(link, base=1., offset=0., drop_flag=0, timetags_as_start=True,
 	vals
 		start/stop intervals of the averages.
 	res
-		averaged link data (all columns, so average timetag, average delta and average flag).
+		averaged link object.
 	count
 		number of averaged point for each intervals.
 
@@ -523,6 +559,10 @@ def save_link_to_dir(dir, link, extra_names=[], message='', time_format='mjd', y
 	else:
 		raise ValueError("Unrecognized time_format. Valid formats are 'iso', 'mjd' and 'unix'.")
 
+	if link.step <= 1:
+		ffmt = '{:.0f}'
+	else:
+		ffmt = '{:.6f}'
 
 	# save metadata to yaml
 	metadata = {'name': link.name}
@@ -551,7 +591,7 @@ def save_link_to_dir(dir, link, extra_names=[], message='', time_format='mjd', y
 		metadata['uB_sys'] = link.oscB.systematic_uncertainty
 
 	if link.step != 1:
-		metadata['interval'] = link.step
+		metadata['interval'] = float(link.step)
 
 	with open(os.path.join(sub, link.name+'.yml'), 'w') as metafile:
 		# print(metadata)
@@ -580,7 +620,7 @@ def save_link_to_dir(dir, link, extra_names=[], message='', time_format='mjd', y
 
 		names = ['t', 'ΔA→B', 'flag'] + extra_names 
 		#yfmt = '{{:.{}e}}'.format(digits)
-		fmtlst = [time_format, yfmt, '{:.0f}'] + ['{}']*(link.data.shape[1]-3)
+		fmtlst = [time_format, yfmt, ffmt] + ['{}']*(link.data.shape[1]-3)
 		fmt = '\t'.join(fmtlst) + '\n'
 
 		col_len = [len(fmtlst[0].format(time_converter(link.data[0][0])))] + [len(f.format(d)) for f, d in zip(fmtlst[1:], link.data[0,1:])]
